#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"
#include "rlparser.h"

gboolean cleanup_and_quit(GtkWidget *any_widget) {
//Add code to clean up stuff and free memory here!!!
  GtkWidget *initconf_app, *dialog, *save_button;

  initconf_app = lookup_widget(GTK_WIDGET(any_widget), "initconf_app");
  save_button = lookup_widget(GTK_WIDGET(any_widget), "save_button");
  
  if(GTK_WIDGET_IS_SENSITIVE(save_button)) {
    dialog = gtk_message_dialog_new (GTK_WINDOW(initconf_app),
                                     GTK_DIALOG_MODAL,
                                     GTK_MESSAGE_QUESTION,
                                     GTK_BUTTONS_OK_CANCEL,
                                     "Quit without saving changes?");
    if(gtk_dialog_run(GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
      gtk_main_quit();
      return FALSE;
    }
    gtk_widget_destroy (dialog);
    return TRUE;
  } else {
    gtk_main_quit();
    return FALSE;  
  }
}

void
on_save1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
  save_rl(GTK_WIDGET(menuitem));
}

void
on_quit1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
  cleanup_and_quit(GTK_WIDGET(menuitem));
}

void
on_properties1_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
  gnome_appbar_push(GNOME_APPBAR(lookup_widget(GTK_WIDGET(menuitem), "appbar1")), "This function is not yet implemented!");  
}

void
on_preferences1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
  gnome_appbar_push(GNOME_APPBAR(lookup_widget(GTK_WIDGET(menuitem), "appbar1")), "This function is not yet implemented!");  
}

void
on_about1_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
  GtkWidget *about = create_initconf_about();
  gtk_widget_show(about);;  
}

void
on_save_button_clicked                 (GtkToolButton   *toolbutton,
                                        gpointer         user_data)
{
  save_rl(GTK_WIDGET(toolbutton));
}

void
on_quit_button_clicked                 (GtkToolButton   *toolbutton,
                                        gpointer         user_data)
{
  cleanup_and_quit(GTK_WIDGET(toolbutton));
}

gboolean on_initconf_app_delete_event    (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
  return cleanup_and_quit(widget);
}

void
on_runlevel_combo_changed               (GtkComboBox     *combobox,
                                        gpointer         user_data)
{
  update_rllist(combobox);
}

void
on_add_button_clicked                   (GtkButton       *button,
                                        gpointer         user_data)
{
  add_to_rl(GTK_WIDGET(button));
}

void
on_remove_button_clicked                (GtkButton       *button,
                                        gpointer         user_data)
{
  remove_from_rl(GTK_WIDGET(button));
}

void
on_service_list_cursor_changed         (GtkTreeView     *treeview,
                                        gpointer         user_data)
{
  GtkWidget *add_button, *runlevel_combo;
  GtkTreeIter iter;

  add_button = lookup_widget(GTK_WIDGET(treeview), "add_button");
  runlevel_combo = lookup_widget(GTK_WIDGET(treeview), "runlevel_combo");

  if(gtk_combo_box_get_active_iter(GTK_COMBO_BOX(runlevel_combo), &iter))
    gtk_widget_set_sensitive(add_button, TRUE);
}

void
on_runlevel_list_cursor_changed        (GtkTreeView     *treeview,
                                        gpointer         user_data)
{
  GtkWidget *remove_button;

  remove_button = lookup_widget(GTK_WIDGET(treeview), "remove_button");

  gtk_widget_set_sensitive(remove_button, TRUE);
}

void
on_new_runlevel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data)
{
  GtkWidget *initconf_app;
  GtkWidget *initconf_new_runlevel = create_initconf_new_runlevel();
  initconf_app = lookup_widget(GTK_WIDGET(button), "initconf_app");
  g_object_set_data(G_OBJECT(initconf_new_runlevel), "initconf_app", initconf_app);
  
  gtk_widget_show(initconf_new_runlevel);
}

void
on_cancel_new_runlevel_button_clicked  (GtkButton       *button,
                                        gpointer         user_data)
{
  GtkWidget *initconf_new_runlevel;
  initconf_new_runlevel = lookup_widget(GTK_WIDGET(button), "initconf_new_runlevel");
  gtk_widget_destroy(initconf_new_runlevel);
}

void
on_ok_new_runlevel_button_clicked      (GtkButton       *button,
                                        gpointer         user_data)
{
  GtkWidget *initconf_new_runlevel, *new_runlevel_name_entry;
  GtkWidget *initconf_app;
  
  initconf_new_runlevel = lookup_widget(GTK_WIDGET(button), "initconf_new_runlevel");
  new_runlevel_name_entry = lookup_widget(GTK_WIDGET(button), "new_runlevel_name_entry");
  initconf_app = g_object_get_data(G_OBJECT(initconf_new_runlevel), "initconf_app");
  
  new_runlevel(GTK_WIDGET(initconf_app), gtk_entry_get_text(GTK_ENTRY(new_runlevel_name_entry)));
  gtk_widget_destroy(initconf_new_runlevel);
}

void
on_service_list_row_activated          (GtkTreeView     *treeview,
                                        GtkTreePath     *path,
                                        GtkTreeViewColumn *column,
                                        gpointer         user_data)
{
  GtkWidget *initconf_show_service, *initconf_app;
  
  initconf_show_service = create_initconf_show_service();
  initconf_app = lookup_widget(GTK_WIDGET(treeview), "initconf_app");
  g_object_set_data(G_OBJECT(initconf_show_service), "initconf_app", initconf_app);

  load_service(initconf_show_service, treeview);
  gtk_widget_show(initconf_show_service);
}


void
on_runlevel_list_row_activated         (GtkTreeView     *treeview,
                                        GtkTreePath     *path,
                                        GtkTreeViewColumn *column,
                                        gpointer         user_data)
{

}

